@@ -8,13 +8,11 @@ use 5.006;
 use strict;
 use warnings;
 BEGIN { *DEBUG = sub () {0} unless defined &DEBUG } # setup a DEBUG constant
-use vars qw(
- @EXPORT @EXPORT_OK $VERSION
- %D %Card2ord %Mult
-);
-$VERSION = '2.02';
-@EXPORT    = ();
-@EXPORT_OK = qw( num2en num2en_ordinal );
+
+our $VERSION = '2.03';
+our @EXPORT    = ();
+our @EXPORT_OK = qw( num2en num2en_ordinal );
+our (%D, %Card2ord, %Mult);
 
 @D{0 .. 20, 30,40,50,60,70,80,90} = qw|
  zero
@@ -84,9 +82,9 @@ sub num2en {
   $sign = $1 if $x =~ s/^([-+])//s;
   
   my($int, $fract);
-  if(    $x =~ m<^\d+$>          ) { $int = $x }
-  elsif( $x =~ m<^(\d+)\.(\d+)$> ) { $int = $1; $fract = $2 }
-  elsif( $x =~ m<^\.(\d+)$>      ) { $fract = $1 }
+  if(    $x =~ m<^[0-9]+$>          ) { $int = $x }
+  elsif( $x =~ m<^([0-9]+)\.([0-9]+)$> ) { $int = $1; $fract = $2 }
+  elsif( $x =~ m<^\.([0-9]+)$>      ) { $fract = $1 }
   else {
     DEBUG and print "Not a number: \"orig\"\n";
     return undef;
@@ -122,7 +120,7 @@ sub _fract2en {    # "1234" => "point one two three four"
 
 sub _int2en {
   return undef unless defined $_[0] and length $_[0]
-   and $_[0] =~ m/^\d+$/s;
+   and $_[0] =~ m/^[0-9]+$/s;
 
   my($x) = $_[0];
 
@@ -146,7 +144,7 @@ sub _int2en {
 
 sub _bigint2en {
   return undef unless defined $_[0] and length $_[0]
-   and $_[0] =~ m/^\d+$/s;
+   and $_[0] =~ m/^[0-9]+$/s;
 
   my($x) = $_[0];
 
@@ -155,7 +153,7 @@ sub _bigint2en {
   {
     my $groupnum = 0;
     my $num;
-    while( $x =~ s<(\d{1,3})$><>s ) { # pull at most three digits from the end
+    while( $x =~ s<([0-9]{1,3})$><>s ) { # pull at most three digits from the end
       $num = $1 + 0;
       unshift @chunks, [ $num, $groupnum ] if $num;
       ++$groupnum;
@@ -225,11 +223,11 @@ sub _e2en {
       ^(
         [-+]?  # leading sign
         (?:
-          [\d,]+  |  [\d,]*\.\d+  # number
+          [0-9,]+  |  [0-9,]*\.[0-9]+  # number
         )
        )
       [eE]
-      ([-+]?\d+)   # mantissa, has to be an integer
+      ([-+]?[0-9]+)   # mantissa, has to be an integer
       $
     >x
   ) {
@@ -347,7 +345,7 @@ a numeric fraction (eg "3/4") into words ("three quarters").
 
 =head1 REPOSITORY
 
-L<https://github.com/neilbowers/Lingua-EN-Numbers>
+L<https://github.com/neilb/Lingua-EN-Numbers>
 
 =head1 COPYRIGHT
 
